@@ -22,9 +22,9 @@
 
 static CalBackendWCAPClass *parent_class = NULL;
 
-#define d(x)	x
+#define d(x)
 
-G_DEFINE_TYPE (CalBackendWCAPEvents, cal_backend_wcap_events,  CAL_BACKEND_WCAP_TYPE);
+G_DEFINE_TYPE (CalBackendWCAPEvents, cal_backend_wcap_events,  CAL_BACKEND_WCAP_TYPE)
 
 static gboolean
 compare_dates (ECalComponentDateTime *adt, ECalComponentDateTime *bdt)
@@ -862,7 +862,9 @@ cal_backend_wcap_events_create_object (ECalBackendSync *backend, EDataCal *cal,
 	d(printf("cal_backend_wcap_events_create_object(%p, %s)\n", backend, *calobj));
 
 	result = cal_backend_wcap_events_update_objects (backend, cal, *calobj, mod, NULL);
+/*
 	*calobj = NULL;
+*/
 
 	return result;
 }
@@ -873,6 +875,8 @@ cal_backend_wcap_events_modify_object (ECalBackendSync *backend, EDataCal *cal,
 {
 	ECalBackendSyncStatus result = GNOME_Evolution_Calendar_Success;
 
+	g_return_val_if_fail (calobj != NULL, GNOME_Evolution_Calendar_InvalidObject);
+
 	d(printf("cal_backend_wcap_events_modify_object(%p, %s)\n", backend, calobj));
 
 	result = cal_backend_wcap_events_update_objects (backend, cal, calobj, mod, old_object);
@@ -1020,6 +1024,8 @@ cal_backend_wcap_events_receive_objects (ECalBackendSync *backend, EDataCal *cal
 	icalcomponent_kind kind;
 	guint error_code;
 
+	g_return_val_if_fail (calobj != NULL, GNOME_Evolution_Calendar_InvalidObject);
+
 	d(printf("cal_backend_wcap_receive_objects(%p, %p, %s)\n", backend, cal, calobj));
 
 	g_return_val_if_fail (IS_CAL_BACKEND_WCAP (wcap), GNOME_Evolution_Calendar_OtherError);
