@@ -915,6 +915,20 @@ clone_prefs (SunOneConnectionPreferences *prefs)
 	return copy;
 }
 
+static gboolean
+already_in_subscriptions (GList *subscriptions, const char *calid)
+{
+	GList *l;
+
+	for (l = subscriptions; l != NULL; l = l->next) {
+		SunOneCalendarSubscription *sub = l->data;
+		if (!strcmp (sub->calid, calid)) 
+			return TRUE;
+	}
+
+	return FALSE;
+}
+
 static void
 parse_subscriptions (SunOneConnection *connection, const gchar *val)
 {
@@ -932,7 +946,7 @@ parse_subscriptions (SunOneConnection *connection, const gchar *val)
 		parts = g_strsplit (items[n], "$", 0);
 
 		if (parts) {
-			if (parts[0] != NULL) {
+			if (parts[0] != NULL && !already_in_subscriptions (priv->prefs->subscriptions, parts[0])) {
 				sub = g_new0 (SunOneCalendarSubscription, 1);
 				sub->calid = g_strdup (parts[0]);
 				if (parts[1] != NULL)
